/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998 Benjamin Geer
 * Email: beroul@yahoo.com
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
 
package freemarker.template;

/**
 * An interface for self-updating caches of compiled <tt>Template</tt>s.
 */
public interface TemplateCache {
    /**
     * Registers a <tt>CacheListener</tt> for this <tt>TemplateCache</tt>.
     *
     * @param CacheListener the <tt>CacheListener</tt> to be registered.
     * @see CacheListener
     */
    public void addCacheListener(CacheListener listener);

    /**
     * Unregisters a <tt>CacheListener</tt> for this <tt>TemplateCache</tt>.
     *
     * @param CacheListener the <tt>CacheListener</tt> to be unregistered.
     * @see CacheListener
     */
    public void removeCacheListener(CacheListener listener);

    /**
     * Gets a template from the cache.
	 *
	 * @param name a string uniquely identifying the template.
	 * @return the template corresponding to the name, or null if not found.
	 */
    public Template getTemplate(String name);

    /**
     * Begins automatic updates of the cache.
     */
    public void startAutoUpdate();

    /**
     * Stops automatically updating the cache.
     */
    public void stopAutoUpdate();
}
